@@ -9,6 +9,7 @@ import subprocess
 # import traceback
 import re
 import os
+import git
 
 _CMD_PATH = 'git'
 
@@ -279,26 +280,35 @@ def get_statuses(dirs):
     return statuses
 
 
+# def is_repository(_dir='.'):
+#     # example: "git status"
+#     try:
+#         curr_dir = os.getcwd()
+#         dst_dir = os.path.abspath(_dir)
+#         if curr_dir != dst_dir:
+#             os.chdir(dst_dir)
+
+#         args = []
+#         args.append(_CMD_PATH)
+#         args.append('status')
+
+#         subprocess.check_call(args, stderr=subprocess.STDOUT)
+
+#         return True
+#     except subprocess.CalledProcessError:
+#         return False
+#     finally:
+#         if curr_dir != dst_dir:
+#             os.chdir(curr_dir)
+
+
+# 优化实现方式
 def is_repository(_dir='.'):
-    # example: "git status"
     try:
-        curr_dir = os.getcwd()
-        dst_dir = os.path.abspath(_dir)
-        if curr_dir != dst_dir:
-            os.chdir(dst_dir)
-
-        args = []
-        args.append(_CMD_PATH)
-        args.append('status')
-
-        subprocess.check_call(args, stderr=subprocess.STDOUT)
-
+        _ = git.Repo(_dir).git_dir
         return True
-    except subprocess.CalledProcessError:
+    except git.exc.InvalidGitRepositoryError:
         return False
-    finally:
-        if curr_dir != dst_dir:
-            os.chdir(curr_dir)
 
 
 # 获取git状态信息
